# Replapi-it-Python-Parser 

Hiya! [@darkdarcool](https://github.com/darkdarcool) here! This is a module made for you to parse json from the very good module that can be found [here](https://https://github.com/ReplAPI-it/ReplAPI.it-Python). Since it returns raw json, and the way to make it nicer would be too big, and we don't want the user to HAVE to import the json module to use it and keep on decoding, it, I took the challenge of making a module here, that would return to you the json! I hope you enjoy it, and if you prefer the json module, go for it. 

# Installation 

Please have pip installed and in the terminal do:
```
pip install THISMODULELOL
```
And then you can use the parser here! 

# Usage 
Put usage here, when the first part of the module is done.

# Contributing 
Please visit the [put contributing md here](), and go ahead! While there is very low chance that if you're not working on the main package, I will invite you, contributions and pull requests are encouraged!